==> regina-normal_7.1.orig.tar.gz: regina-7.1/python/maths/numbertheory.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2022, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include "../pybind11/pybind11.h"
#include "../pybind11/stl.h"
#include "maths/numbertheory.h"
#include <numeric>

void addNumberTheory(pybind11::module_& m) {
    m.def("reducedMod", regina::reducedMod);
    m.def("gcd", std::gcd<long, long>); // deprecated
    m.def("gcdWithCoeffs", pybind11::overload_cast<long, long>(
        &regina::gcdWithCoeffs));
    m.def("lcm", std::lcm<long, long>); // deprecated
    m.def("modularInverse", regina::modularInverse);
}

==> regina-normal_7.2.orig.tar.gz: regina-7.2/python/maths/numbertheory.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2022, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include "../pybind11/pybind11.h"
#include "../pybind11/stl.h"
#include "maths/numbertheory.h"
#include "../helpers/docstrings.h"
#include "../docstrings/maths/numbertheory.h"
#include <numeric>

void addNumberTheory(pybind11::module_& m) {
    RDOC_SCOPE_BEGIN_MAIN

    m.def("reducedMod", regina::reducedMod, rdoc::reducedMod);
    m.def("gcd", std::gcd<long, long>, rdoc::gcd); // deprecated
    m.def("gcdWithCoeffs", pybind11::overload_cast<long, long>(
        &regina::gcdWithCoeffs), rdoc::gcdWithCoeffs);
    m.def("lcm", std::lcm<long, long>, rdoc::lcm); // deprecated
    m.def("modularInverse", regina::modularInverse, rdoc::modularInverse);

    RDOC_SCOPE_END
}
